#ifdef IDTLIB_EXPORTS
#define IDTLIB_API __declspec(dllexport) _stdcall
#else
#define IDTLIB_API __declspec(dllimport) _stdcall
#endif

// NOTE:  As implemented, all return codes are equivalent to device driver return codes
//        A return code of 0 indicates SUCCESS.
//        A return code of -1 indicates the DLL call failed
//        All other error codes indicate the driver error code

//**********************************************
// The following APIs are added for Spectrum III
//**********************************************
// This API is used to set the product version so that the DLL
// would know what API would be available to user according to
// versions of the reader used, i.e. whether it is SP1, SP2 or SP3, etc.
LONG IDTLIB_API IdtSetProdVer (
	IN SCARDHANDLE hCard);


//*********************************************
// The following APIs are added for Spectrum II
//*********************************************

// This API is used to select a card to read or write
LONG IDTLIB_API IdtCardSelect (
	IN SCARDHANDLE hCard,
	IN 	BYTE 	cardSelect);

// The card selection is defined as follows:
#define		CARD_SEL_MAIN		0
#define		CARD_SEL_SAM1		1
#define		CARD_SEL_SAM2		2
#define		CARD_SEL_SAM3		3
#define		CARD_SEL_SAM4		4
#define		CARD_SEL_SAM5		5


// This API is used to set the MSR read mode.
LONG IDTLIB_API IdtSetMSRReadMode (
	IN SCARDHANDLE hCard,
	IN 	BYTE 	readMode);

//The modes are defined as:
#define 	MSR_MODE_DISABLE	'0'
#define 	MSR_MODE_AUTO_TX	'1'	// auto-tranismit mode
#define 	MSR_MODE_BUFFER		'2'	// buffered mode

// This API is used to reset the MSR buffer (clear the buffer) 
// and put the reader into disarmed state.
LONG IDTLIB_API IdtResetMSRBuffer (
	IN SCARDHANDLE hCard);

// This API is used to set the LED color, provided the reader is 
// set into the host controlled mode.
LONG IDTLIB_API IdtSetLEDColor (
	IN SCARDHANDLE hCard,
	IN 	BYTE 	LEDColor);

// The LED colors are defined as:
#define		LED_OFF			'0'
#define		LED_GREEN		'1'
#define 	LED_RED			'2'
#define		LED_AMBER		'3'

//*********************************************
// End--Spectrum II APIs
//*********************************************

// Get the version of the DLL
LONG IDTLIB_API IdtGetVersion (
  OUT BYTE *versionBuffer,
  IN OUT DWORD *versionBufferLength
);

// This API call the driver synchronously and wait for the data to return.
// All other calls are blocked. This call is obsolete. User should use
// IdtStartMagstripe and IdtPollMagstripe instead. 
LONG IDTLIB_API IdtReadMagstripe (
	IN SCARDHANDLE hCard,
	OUT		BYTE	*outputBuffer,
	IN OUT	DWORD	*outputBufferLength,
	IN		BOOLEAN TurnCardOff
);

// Start a thread to call driver for magstripe data. The call returns immediately so 
// we don't hold up the calling application. The thread will call driver and wait for
// the data.
LONG IDTLIB_API IdtStartMagstripe (
	IN SCARDHANDLE hCard,
	IN	DWORD	outputBufferLength,
	IN	BOOLEAN TurnCardOff
);

// Check to see if the call to driver has returned, if so read data into buffer
LONG IDTLIB_API IdtPollMagstripe (
	IN SCARDHANDLE hCard,		
	IN  BYTE	TrackSelect,	// added v1.08
	OUT BYTE 	*outputBuffer,
	OUT DWORD 	*outputBufferLength
);	

#define		MSR_RD_ANY_TRK		'0'
#define		MSR_RD_TRK_1		'1'
#define		MSR_RD_TRK_2		'2'
#define		MSR_RD_TRK_12		'3'
#define		MSR_RD_TRK_3		'4'
#define		MSR_RD_TRK_13		'5'
#define		MSR_RD_TRK_23		'6'
#define		MSR_RD_ALL_TRK		'7'

// Send a command to the reader
LONG IDTLIB_API IdtSendCommand (
  IN SCARDHANDLE hCard,
  IN BYTE *commandBuffer,
  IN DWORD commandLength,
  OUT BYTE *responseBuffer,
  IN OUT DWORD *responseBufferLength 
);

// Send the Latch command to the reader
LONG IDTLIB_API IdtLatch (
  IN SCARDHANDLE hCard
);

// Send the Unlatch command to the reader
LONG IDTLIB_API IdtUnlatch (
  IN SCARDHANDLE hCard
);

// Send the power off command to the card
LONG IDTLIB_API IdtCardOff (
  IN SCARDHANDLE hCard
);

// Set the timeout for waiting for magstripe data
LONG IDTLIB_API IdtSetMagstripeTimeout (
  IN SCARDHANDLE hCard,
  IN  UCHAR timeout
);

// Get the timeout for magstripe data
LONG IDTLIB_API IdtGetMagstripeTimeout (
  IN SCARDHANDLE hCard,
  OUT UCHAR *timeout
);

// Get the driver version
// NOTE: The drvrVersion buffer should be at least 10 bytes long
LONG IDTLIB_API IdtGetDriverVersion (
  IN SCARDHANDLE hCard,
  OUT UCHAR *drvrVersion
);

// Get the version of the firmware on the reader
// NOTE: The firmwareVersion buffer should be at least 50 bytes long
LONG IDTLIB_API IdtGetFirmwareVersion (
  IN SCARDHANDLE hCard,
  OUT UCHAR *firmwareVersion
);

// Get the current (cached) state of the reader
// readerState is defined as follows:
// bit 0: power, 0 => not ready, 1 => ready
// bit 1: card, 0 => card not seated, 1 => card seated
// bit 2: latch, 0 => released, 1 => closed 
// bit 3: card, 0 => card not present, 1 => card present 
// This version only returns the cached version of reader state in the driver
// It avoids sending a smart card command to the reader and should be used when
// the user is only interested in the info relating to whether the card is seated,
// present, or removed. Since reader state is updated when card notification is 
// received, it may not reflect the TRUE current reader state as far as other state
// information such as latch state is concern. To obtain the TRUE reader state
// of the reader, use IdtGetReaderStateDirect. 
LONG IDTLIB_API IdtGetReaderState(
  IN SCARDHANDLE hCard,
  OUT UCHAR *readerState
);

// Get the current state of the reader
// readerState is defined as follows:
// bit 0: power, 0 => not ready, 1 => ready
// bit 1: card, 0 => card not seated, 1 => card seated
// bit 2: latch, 0 => released, 1 => closed 
// bit 3: card, 0 => card not present, 1 => card present 
// Note this version of API will send a smart card command to the
// reader. If you are only interested in the current card state, i.e. whether
// the card is seated, present, or removed, use IdtGetReaderState which returns
// the cached state without sending a smart card command to the reader.
// Having these 2 APIs (IdtGetReaderState and IdtGetReaderStateDirect) is ugly,
// but we have to do it this way to maintain backward compatibility.
LONG IDTLIB_API IdtGetReaderStateDirect(
  IN SCARDHANDLE hCard,
  OUT UCHAR *readerState
);
